@@ -92,9 +92,6 @@ newPowerRelationFromString("12 > 1 ~ {} > 2", asWhat = as.numeric)
 ## ---- echo=FALSE, results='asis'----------------------------------------------
 xfun::file_string("tables/functionTable.html")
 
-## ---- echo=FALSE, results='asis'----------------------------------------------
-xfun::file_string("tables/functionTable.tex")
-
 ## -----------------------------------------------------------------------------
 pr <- newPowerRelationFromString("ab > ac ~ bc > a ~ c > {} > b")
 
@@ -147,9 +144,6 @@ pr
 ## ---- echo=FALSE, results='asis'----------------------------------------------
 xfun::file_string('tables/prObject.html')
 
-## ---- echo=FALSE, results='asis'----------------------------------------------
-xfun::file_string('tables/prObject.tex')
-
 ## -----------------------------------------------------------------------------
 prAtts <- newPowerRelation(c(2,2,1,1,2), ">", c(1,1,1), "~", c())
 prAtts
